package WebGUI::i18n::Dutch::Asset_Calendar;
use utf8;
our $I18N = {
  'Add' => {
    'lastUpdated' => '1231520061',
    'message' => 'Toevoegen'
  },
  'Add a feed' => {
    'lastUpdated' => '1231711258',
    'message' => 'Voeg een toevoer toe'
  },
  'DN' => {
    'lastUpdated' => '1231711449',
    'message' => 'DN'
  },
  'Feed URL' => {
    'lastUpdated' => '1231711386',
    'message' => 'URL van de toevoer'
  },
  'New Day' => {
    'lastUpdated' => '1229699565',
    'message' => 'Nieuwe dag'
  },
  'New Month' => {
    'lastUpdated' => '1229699580',
    'message' => 'Nieuwe maand'
  },
  'New Year' => {
    'lastUpdated' => '1229699592',
    'message' => 'Nieuw jaar'
  },
  'UP' => {
    'lastUpdated' => '1231711438',
    'message' => 'UP'
  },
  'add event' => {
    'lastUpdated' => '1199098698',
    'message' => 'Voeg evenement toe'
  },
  'admin' => {
    'lastUpdated' => '1189118736',
    'message' => 'Een voorwaardelijke variabele die waar is als de site in Admin-mode staat.'
  },
  'adminControls' => {
    'lastUpdated' => '1207905593',
    'message' => 'Met deze iconen kun je het object bewerken, knippen, kopi&euml;ren verwijderen en van plaats veranderen.'
  },
  'asset not committed' => {
    'lastUpdated' => '1222875800',
    'message' => '<h1>FOUT!</h1><p>Deze kalender moet eerst ingevoerd worden voordat er een nieuw evenement gemaakt kan worden.</p>'
  },
  'assetName' => {
    'lastUpdated' => '1166193349',
    'message' => 'Kalender'
  },
  'current' => {
    'lastUpdated' => '1205831409',
    'message' => 'huidig'
  },
  'dayAbbr' => {
    'lastUpdated' => '1189118976',
    'message' => 'De afkorting voor de naam van de huidige dag.'
  },
  'dayCurrent' => {
    'lastUpdated' => '1269433174',
    'message' => 'Een functie die waar is als deze dag vandaag is.'
  },
  'dayName' => {
    'lastUpdated' => '1189118985',
    'message' => 'De naam van de huidige dag.'
  },
  'dayNames' => {
    'lastUpdated' => '1269433214',
    'message' => 'Een functie die alle namen en afkortingen van de dagen van de week ophaalt.'
  },
  'dayOfMonth' => {
    'lastUpdated' => '1189119012',
    'message' => 'Welke dag van de maand deze dag is. Dit is een geheel getal van 1 tot en met 31.'
  },
  'dayOfWeek' => {
    'lastUpdated' => '1189119031',
    'message' => 'Welke dag van de week deze dag is. Dit is een geheel getal van 1 tot en met 7.'
  },
  'dayUrl' => {
    'lastUpdated' => '1269433256',
    'message' => 'Een URL waar alle evenementen op die dag bekeken kunnen worden.'
  },
  'days' => {
    'lastUpdated' => '1189119161',
    'message' => 'Binnen deze loop zijn alle gebeurtenissen en labels voor de dagen beschikbaar. Alle dagen in de week zijn beschikbaar, of ze gebeurtenissen bevatten of niet.'
  },
  'defaultDate description' => {
    'lastUpdated' => '1166193403',
    'message' => 'De datum die standaard aan de gebruiker wordt getoond.'
  },
  'defaultDate label' => {
    'lastUpdated' => '1166193414',
    'message' => 'Standaard Datum'
  },
  'defaultDate value current' => {
    'lastUpdated' => '1166193431',
    'message' => 'De huidige datum'
  },
  'defaultDate value first' => {
    'lastUpdated' => '1166193442',
    'message' => 'De eerste gebeurtenis in de kalender'
  },
  'defaultDate value last' => {
    'lastUpdated' => '1166193452',
    'message' => 'De laaste gebeurtenis in de kalender'
  },
  'defaultView description' => {
    'lastUpdated' => '1166193492',
    'message' => 'De standaard weergave voor de gebruiker.'
  },
  'defaultView label' => {
    'lastUpdated' => '1166193502',
    'message' => 'Standaard weergave'
  },
  'defaultView value day' => {
    'lastUpdated' => '1166193508',
    'message' => 'Dag'
  },
  'defaultView value list' => {
    'lastUpdated' => '1204298959',
    'message' => 'Lijst'
  },
  'defaultView value month' => {
    'lastUpdated' => '1166193513',
    'message' => 'Maand'
  },
  'defaultView value week' => {
    'lastUpdated' => '1166193517',
    'message' => 'Week'
  },
  'dmy' => {
    'lastUpdated' => '1189119199',
    'message' => 'De datum van deze dag in dd-mm-yyyy formaat. Hierbij is yyyy het jaar, mm de maand en dd de dag.'
  },
  'editForm icalInterval description' => {
    'lastUpdated' => '1204299141',
    'message' => 'Tijdsinterval dat getoond wordt in de ICalendar toevoer'
  },
  'editForm icalInterval label' => {
    'lastUpdated' => '1204299194',
    'message' => 'ICalendar toevoer interval'
  },
  'editForm listViewPageInterval description' => {
    'lastUpdated' => '1204299241',
    'message' => 'Tijdsinterval dat getoond wordt in een enkele pagina van de lijst'
  },
  'editForm listViewPageInterval label' => {
    'lastUpdated' => '1204299264',
    'message' => 'Lijst pagina interval'
  },
  'editForm templateIdList description' => {
    'lastUpdated' => '1207916213',
    'message' => 'Dit sjabloon toont de kalender in een lijst layout.'
  },
  'editForm templateIdList label' => {
    'lastUpdated' => '1204299311',
    'message' => 'Lijst sjabloon'
  },
  'editForm templateIdPrintList description' => {
    'lastUpdated' => '1204299339',
    'message' => 'Dit sjabloon print de kalender als een lijst.'
  },
  'editForm templateIdPrintList label' => {
    'lastUpdated' => '1204299357',
    'message' => 'Print lijst sjabloon'
  },
  'editForm workflowIdCommit description' => {
    'lastUpdated' => '1213625120',
    'message' => 'Selecteer een workflow die gebruikt wordt voor het inzenden van evenementen wanneer deze bewerkt of aangemaakt worden.'
  },
  'editForm workflowIdCommit label' => {
    'lastUpdated' => '1213625455',
    'message' => 'Workflow voor toevoegen evenementen'
  },
  'editor' => {
    'lastUpdated' => '1189119228',
    'message' => 'Een voorwaardelijke variabele die waar is als de gebruiker gebeurtenissen in de kalender mag bewerken.'
  },
  'end date' => {
    'lastUpdated' => '1205831420',
    'message' => 'Einddatum'
  },
  'endDayAbbr' => {
    'lastUpdated' => '1189119403',
    'message' => 'De afkorting van de naam van de dag waarin deze week eindigt.'
  },
  'endDayName' => {
    'lastUpdated' => '1189119424',
    'message' => 'De naam van de dag waarin deze week eindigt.'
  },
  'endDayOfMonth' => {
    'lastUpdated' => '1189119436',
    'message' => 'De dag van de maand waarin deze week eindigt. Dit is een geheel getal van 1 tot en met 31.'
  },
  'endMonth' => {
    'lastUpdated' => '1189119455',
    'message' => 'Het nummer (1-12) van de maand waarin deze week eindigt.'
  },
  'endMonthAbbr' => {
    'lastUpdated' => '1189119445',
    'message' => 'De afkorting van de naam van de maand waarin deze week eindigt.'
  },
  'endMonthName' => {
    'lastUpdated' => '1189119463',
    'message' => 'De naam van de maand waarin deze week eindigt.'
  },
  'endYear' => {
    'lastUpdated' => '1189119391',
    'message' => 'Het jaar waarin deze week eindigt.'
  },
  'epoch' => {
    'lastUpdated' => '1189119858',
    'message' => 'De datum van deze dag in epoch formaat. (Een epoch is een punt in de tijd dat gekozen is als het begin van een tijdperk. In dit geval 1 januari 1970 T00:00Z. Z slaat hier op de Universal Coordinated Time, in de Zulu tijdzone. De tijd in epochformat is de tijd in seconden sinds 1970,1,1 Z.)'
  },
  'events dayVar' => {
    'lastUpdated' => '1189119883',
    'message' => 'In deze loop zijn alle gebeurtenissen voor dit uur beschikbaar.'
  },
  'events weekVar' => {
    'lastUpdated' => '1189119897',
    'message' => 'In deze loop zijn alle gebeurtenissen voor deze dag beschikbaar.'
  },
  'extrasUrl' => {
    'lastUpdated' => '1189119909',
    'message' => 'Een URL naar de WebGUI extras directory.'
  },
  'feeds' => {
    'lastUpdated' => '1166193533',
    'message' => 'Feeds'
  },
  'groupIdEventEdit description' => {
    'lastUpdated' => '1166193553',
    'message' => 'Leden van deze groep kunnen gebeurtenissen toevoegen en bewerken in deze kalender.'
  },
  'groupIdEventEdit label' => {
    'lastUpdated' => '1166193570',
    'message' => 'Wie kan gebeurtenissen toevoegen/bewerken?'
  },
  'help calendar dateTime body' => {
    'lastUpdated' => '1207916307',
    'message' => '<p>Deze variabelen zijn beschikbaar voor de meeste datum en tijd objecten in de Kalender.</p><p>Let op: soms hebben deze variabelen een voorvoegsel zoals &quot;start&quot; of &quot;end&quot;. In dat geval wordt de eerste letter van de variabelen hieronder een hoofdletter, dus &quot;monthName&quot; met het voorvoegsel &quot;start&quot; wordt &quot;startMonthName&quot;.  </p>'
  },
  'help calendar dateTime title' => {
    'lastUpdated' => '1204299456',
    'message' => 'Kalender datum/tijd variabelen'
  },
  'help event variables body' => {
    'lastUpdated' => '1204299631',
    'message' => '<p>Wanneer de Kalender een evenement toont, wordt de gehele set van evenement sjabloon variabelen meegeleverd en de naam wordt enigszins veranderd.</p><p>De evenement sjabloon variabele title komt vaneventTitle. De evenement sjabloon variabele &quot;stratDate&quot; komt van &quot;eventStartDate&quot; enzovoort.</p>'
  },
  'help event variables title' => {
    'lastUpdated' => '1204299649',
    'message' => 'Kalender evenement variabelen'
  },
  'help view list body' => {
    'lastUpdated' => '1204299812',
    'message' => 'Deze variabelen zijn beschikbaar voor de kalender lijst'
  },
  'help view list title' => {
    'lastUpdated' => '1204301414',
    'message' => 'Kalender type lijst'
  },
  'helpvar dateTime dayAbbr' => {
    'lastUpdated' => '1204301396',
    'message' => 'De afgekorte naam van de dag (zo)'
  },
  'helpvar dateTime dayName' => {
    'lastUpdated' => '1204301377',
    'message' => 'De naam van de dag (zondag)'
  },
  'helpvar dateTime dayOfMonth' => {
    'lastUpdated' => '1204301364',
    'message' => 'Het nummer van de dag in de maand'
  },
  'helpvar dateTime dayOfWeek' => {
    'lastUpdated' => '1204301350',
    'message' => 'Het nummer van de dag in de week (1 is maandag, 7 is zondag)'
  },
  'helpvar dateTime dmy' => {
    'lastUpdated' => '1204301290',
    'message' => 'De dag, maand en jaar in Europees formaat: DD/MM/JJJJ'
  },
  'helpvar dateTime end' => {
    'lastUpdated' => '1204900795',
    'message' => 'Een set van datum/tijd variabelen met het voorvoegsel &quot;end&quot;. Zie Kalender datum/tijd variabelen voor meer informatie.'
  },
  'helpvar dateTime epoch' => {
    'lastUpdated' => '1204301006',
    'message' => 'De epoch tijd (aantal seconden sinds 1970-01-01 00:00:00). Geschikt om gebruikt te worden in het Datum macro.'
  },
  'helpvar dateTime mdy' => {
    'lastUpdated' => '1204300948',
    'message' => 'De maand, dag en jaar in Amerikaans formaat: MM/DD/JJJJ'
  },
  'helpvar dateTime meridiem' => {
    'lastUpdated' => '1204300913',
    'message' => 'A.M. of P.M.'
  },
  'helpvar dateTime minute' => {
    'lastUpdated' => '1204300725',
    'message' => 'De minuten'
  },
  'helpvar dateTime month' => {
    'lastUpdated' => '1204300716',
    'message' => 'Het nummer van de maand (01 voor Januari)'
  },
  'helpvar dateTime monthAbbr' => {
    'lastUpdated' => '1204300695',
    'message' => 'De afgekorte naam van de maand (&quot;Jan&quot;)'
  },
  'helpvar dateTime monthName' => {
    'lastUpdated' => '1204300675',
    'message' => 'De naam van de maand (&quot;Januari&quot;)'
  },
  'helpvar dateTime second' => {
    'lastUpdated' => '1204300656',
    'message' => 'De seconden'
  },
  'helpvar dateTime start' => {
    'lastUpdated' => '1227568003',
    'message' => 'Een set van datum/tijd variabelen met het voorvoegsel \'start\'. Zie Kalender datum/tijd variabelen voor meer informatie.'
  },
  'helpvar dateTime year' => {
    'lastUpdated' => '1204300559',
    'message' => 'Het jaar'
  },
  'helpvar dateTime ymd' => {
    'lastUpdated' => '1204300480',
    'message' => 'Het jaar, maand en dag in een ISO formaat: JJJJ-MM-DD'
  },
  'helpvar newDay' => {
    'lastUpdated' => '1204300440',
    'message' => 'Deze variabele is waar wanneer het huidige evenement op een andere dag is dan het vorige evenement.'
  },
  'helpvar newMonth' => {
    'lastUpdated' => '1204300418',
    'message' => 'Deze variabele is waar wanneer het huidige evenement in een andere maand is dan het vorige evenement.'
  },
  'helpvar newYear' => {
    'lastUpdated' => '1204300375',
    'message' => 'Deze variabele is waar wanneer het huidige evenement in een ander jaar is dan het vorige evenement.'
  },
  'helpvar url_nextPage' => {
    'lastUpdated' => '1204900802',
    'message' => 'Het URL naar de volgende pagina. Als er geen volgende pagina is, bestaat deze variabele niet.'
  },
  'helpvar url_previousPage' => {
    'lastUpdated' => '1204299949',
    'message' => 'Het URL naar de vorige pagina. Als er geen vorige pagina bestaat, bestaat deze variabele niet.'
  },
  'hour12' => {
    'lastUpdated' => '1189119979',
    'message' => 'Het uur in 12 uurs formaat. 2:00 \'s middags is dan 2:00 en niet 14:00.'
  },
  'hour24' => {
    'lastUpdated' => '1189119999',
    'message' => 'Het uur in 24 uurs formaat. 2:00 \'s middags is dan 14:00 en niet 2:00.'
  },
  'hourM' => {
    'lastUpdated' => '1189120050',
    'message' => 'De tekst "am" of "pm" als het uur in respectievelijk de ochtend of de middag plaatsvindt.'
  },
  'hours' => {
    'lastUpdated' => '1189120090',
    'message' => 'In deze loop zijn alle gebeurtenissen en labels voor de uren beschikbaar. Uren zonder gebeurtenissen zijn niet beschikbaar in deze loop.'
  },
  'iCal' => {
    'lastUpdated' => '1199098707',
    'message' => 'iCal'
  },
  'keyword' => {
    'lastUpdated' => '1205852741',
    'message' => 'Trefwoord'
  },
  'label day' => {
    'lastUpdated' => '1205852408',
    'message' => 'Dag'
  },
  'label month' => {
    'lastUpdated' => '1205852423',
    'message' => 'Maand'
  },
  'label search' => {
    'lastUpdated' => '1205852429',
    'message' => 'Zoeken'
  },
  'label week' => {
    'lastUpdated' => '1222166551',
    'message' => 'Week'
  },
  'locale' => {
    'lastUpdated' => '1166193580',
    'message' => 'en_US'
  },
  'mdy' => {
    'lastUpdated' => '1189120120',
    'message' => 'De datum van deze dag in mm-dd-yyyy formaat. Hierbij is yyyy het jaar, mm de maand en dd de dag.'
  },
  'monthAbbr' => {
    'lastUpdated' => '1189120130',
    'message' => 'De afkorting van de naam voor deze maand.'
  },
  'monthCurrent' => {
    'lastUpdated' => '1269433290',
    'message' => 'Een functie die waar is als de kalender de huidige maand toont.'
  },
  'monthEpoch' => {
    'lastUpdated' => '1269434802',
    'message' => 'De epoch tijd van deze maand'
  },
  'monthName' => {
    'lastUpdated' => '1189120138',
    'message' => 'De naam van deze maand.'
  },
  'monthUrl' => {
    'lastUpdated' => '1269435199',
    'message' => 'De URL waar de kalender, die gebruikt wordt voor deze maand, aangepast kan worden.'
  },
  'months' => {
    'lastUpdated' => '1269435240',
    'message' => 'Een functie die de namen en URLs van alle maanden ophaalt.'
  },
  'next day' => {
    'lastUpdated' => '1205852417',
    'message' => 'Volgende dag'
  },
  'next page' => {
    'lastUpdated' => '1205852440',
    'message' => 'Volgende pagina'
  },
  'next week' => {
    'lastUpdated' => '1205852449',
    'message' => 'Volgende week'
  },
  'page x of x' => {
    'lastUpdated' => '1205852478',
    'message' => 'Weergeven pagina %s van %s'
  },
  'pageNextStart' => {
    'lastUpdated' => '1189120163',
    'message' => 'De datum van de volgende dag in de kalender in YYYY-MM-DD (Year, Month, Day) format.'
  },
  'pageNextUrl dayVar' => {
    'lastUpdated' => '1189120176',
    'message' => 'Een URL naar de volgende dag in de kalender.'
  },
  'pageNextUrl monthVar' => {
    'lastUpdated' => '1311843721',
    'message' => 'Een URL naar het volgende jaar in de kalender.'
  },
  'pageNextUrl weekVar' => {
    'lastUpdated' => '1189120259',
    'message' => 'Een URL naar de volgende week in de kalender.'
  },
  'pageNextYear' => {
    'lastUpdated' => '1269435639',
    'message' => 'Het jaar na het geselecteerde jaar in de kalender.'
  },
  'pagePrevStart' => {
    'lastUpdated' => '1189120286',
    'message' => 'De datum van de vorige dag in de kalender in YYYY-MM-DD (Jaar, Maand, Dag) formaat.'
  },
  'pagePrevUrl dayVar' => {
    'lastUpdated' => '1189120297',
    'message' => 'Een URL naar de vorige dag in de kalender.'
  },
  'pagePrevUrl monthVar' => {
    'lastUpdated' => '1311843738',
    'message' => 'Een URL naar het vorige jaar in de kalender.'
  },
  'pagePrevUrl weekVar' => {
    'lastUpdated' => '1189120314',
    'message' => 'Een URL naar de vorige week in de kalender.'
  },
  'pagePrevYear' => {
    'lastUpdated' => '1269435617',
    'message' => 'Het jaar voor het geselecteerde jaar in de kalender.'
  },
  'paramStart' => {
    'lastUpdated' => '1189120325',
    'message' => 'De startdatum van de kalender.'
  },
  'paramType' => {
    'lastUpdated' => '1189120368',
    'message' => 'De tijdseenheid waarin de kalender wordt bekeken. Dit kan "dag", "week" of "maand" zijn.'
  },
  'previous day' => {
    'lastUpdated' => '1205852487',
    'message' => 'Vorige dag'
  },
  'previous page' => {
    'lastUpdated' => '1205852502',
    'message' => 'Vorige pagina'
  },
  'previous week' => {
    'lastUpdated' => '1205852510',
    'message' => 'Vorige week'
  },
  'print' => {
    'lastUpdated' => '1199098719',
    'message' => 'Printen'
  },
  'search results' => {
    'lastUpdated' => '1205852519',
    'message' => 'Zoekresultaten'
  },
  'searchButtonLabel' => {
    'lastUpdated' => '1189120381',
    'message' => 'Zoeken'
  },
  'sortEventsBy description' => {
    'lastUpdated' => '1201182867',
    'message' => 'De volgorde waarin dagelijkse gebeurtenissen worden weergegeven.'
  },
  'sortEventsBy label' => {
    'lastUpdated' => '1201182888',
    'message' => 'Dagelijkse gebeurtenissen sorteer volgorde'
  },
  'sortEventsBy value sequencenumber' => {
    'lastUpdated' => '1201182909',
    'message' => 'Sorteer op rangnummer.'
  },
  'sortEventsBy value time' => {
    'lastUpdated' => '1201182925',
    'message' => 'Sorteer op start of einddatum.'
  },
  'start date' => {
    'lastUpdated' => '1205852527',
    'message' => 'Startdatum'
  },
  'startDayAbbr' => {
    'lastUpdated' => '1189120394',
    'message' => 'De afkorting van de naam van de dag waarmee deze week begint.'
  },
  'startDayName' => {
    'lastUpdated' => '1189120410',
    'message' => 'De naam van de dag waarmee deze week begint.'
  },
  'startDayOfMonth' => {
    'lastUpdated' => '1189120438',
    'message' => 'De dag van de maand waarin deze week begint. Dit is een geheel getal van 1 tot 31.'
  },
  'startMonth' => {
    'lastUpdated' => '1189120459',
    'message' => 'Het nummer (1-12) van de maand waarin deze week begint.'
  },
  'startMonthAbbr' => {
    'lastUpdated' => '1189120477',
    'message' => 'De afkorting van de naam van de maand waarin deze week begint.'
  },
  'startMonthName' => {
    'lastUpdated' => '1189120492',
    'message' => 'De naam van de maand waarin deze week begint.'
  },
  'startYear' => {
    'lastUpdated' => '1189120502',
    'message' => 'Het jaar waarin deze week begint.'
  },
  'subscribe' => {
    'lastUpdated' => '1205852537',
    'message' => 'Inschrijven'
  },
  'subscriberNotifyOffset description' => {
    'lastUpdated' => '1207916695',
    'message' => 'Het aantal dagen dat vooraf gaat aan een notificatie die aangeeft dat de gebeurtenis plaats gaat vinden. '
  },
  'subscriberNotifyOffset label' => {
    'lastUpdated' => '1166193825',
    'message' => 'Abonnee notificatie startwaarde'
  },
  'templateIdDay description' => {
    'lastUpdated' => '1166193871',
    'message' => 'Dit template geeft een kalender weer ingedeeld in dagen'
  },
  'templateIdDay label' => {
    'lastUpdated' => '1166193926',
    'message' => 'Weergave per dag template'
  },
  'templateIdEvent description' => {
    'lastUpdated' => '1166193944',
    'message' => 'Het template dat de details van een gebeurtenis weergeeft.'
  },
  'templateIdEvent label' => {
    'lastUpdated' => '1166193959',
    'message' => 'Details gebeurtenis template'
  },
  'templateIdEventEdit description' => {
    'lastUpdated' => '1166193992',
    'message' => 'Het template om een gebeurtenis te bewerken.'
  },
  'templateIdEventEdit label' => {
    'lastUpdated' => '1166194021',
    'message' => 'Gebeurtenis bewerken template'
  },
  'templateIdMonth description' => {
    'lastUpdated' => '1166194041',
    'message' => 'Dit template geeft de kalender weer ingedeeld in maanden. '
  },
  'templateIdMonth label' => {
    'lastUpdated' => '1166194053',
    'message' => 'Maand-weergave template'
  },
  'templateIdPrintDay description' => {
    'lastUpdated' => '1166194082',
    'message' => 'Dit template print de kalender in weergave per dag.'
  },
  'templateIdPrintDay label' => {
    'lastUpdated' => '1166194098',
    'message' => 'Printen dagweergave template'
  },
  'templateIdPrintEvent description' => {
    'lastUpdated' => '1166194112',
    'message' => 'Het template om de details van een gebeurtenis te printen.'
  },
  'templateIdPrintEvent label' => {
    'lastUpdated' => '1166194124',
    'message' => 'Details gebeurtenis printen template'
  },
  'templateIdPrintMonth description' => {
    'lastUpdated' => '1166194136',
    'message' => 'Dit template print de kalender in maand-weergave.'
  },
  'templateIdPrintMonth label' => {
    'lastUpdated' => '1207916733',
    'message' => 'Maand-weergave printen template'
  },
  'templateIdPrintWeek description' => {
    'lastUpdated' => '1166194159',
    'message' => 'Dit template print de kalender in week-weergave'
  },
  'templateIdPrintWeek label' => {
    'lastUpdated' => '1166194172',
    'message' => 'Week-weergave printen template'
  },
  'templateIdSearch description' => {
    'lastUpdated' => '1166194200',
    'message' => 'Dit template geeft de kalender weer in zoek-weergave'
  },
  'templateIdSearch label' => {
    'lastUpdated' => '1166194208',
    'message' => 'Zoek-weergave template'
  },
  'templateIdWeek description' => {
    'lastUpdated' => '1166194234',
    'message' => 'Dit template geeft de kalender weer ingedeeld per week.'
  },
  'templateIdWeek label' => {
    'lastUpdated' => '1166194243',
    'message' => 'Week-weergave template'
  },
  'urlAdd' => {
    'lastUpdated' => '1189120545',
    'message' => 'De URL om een nieuwe gebeurtenis aan de kalender toe te voegen.'
  },
  'urlDay' => {
    'lastUpdated' => '1189120594',
    'message' => 'De URL om de kalender per dag te bekijken. (In plaats van per week of maand.)'
  },
  'urlIcal' => {
    'lastUpdated' => '1189120691',
    'message' => 'De URL naar de <a href="http://nl.wikipedia.org/wiki/ICal">iCal</a> feed van de kalender. Deze begint met deze maand. '
  },
  'urlMonth' => {
    'lastUpdated' => '1207905667',
    'message' => 'De URL om de kalender per maand te bekijken. (In plaats van per dag of week.)'
  },
  'urlPrint' => {
    'lastUpdated' => '1189120793',
    'message' => 'De URL om de kalender printvriendelijk weer te geven.'
  },
  'urlSearch' => {
    'lastUpdated' => '1189120814',
    'message' => 'De URL naar het zoekformulier waarmee de kalender doorzocht kan worden.'
  },
  'urlWeek' => {
    'lastUpdated' => '1189120836',
    'message' => 'De URL om de kalender per week te bekijken. (In plaats van per dag of per maand.)'
  },
  'view calendar body' => {
    'lastUpdated' => '1189120885',
    'message' => 'De kalender kan bekeken worden per maand, per week of per dag. Elke weergave heeft eigen template variabelen, maar er zijn ook variabelen die beschikbaar zijn in alle templates. Deze staan hieronder:'
  },
  'view calendar day body' => {
    'lastUpdated' => '1189120924',
    'message' => 'Dit template laat alle gebeurtenissen op een dag zien, gesorteerd op uur. '
  },
  'view calendar day title' => {
    'lastUpdated' => '1269436342',
    'message' => 'Sjabloon variabelen kalenderdag'
  },
  'view calendar month body' => {
    'lastUpdated' => '1269436522',
    'message' => 'Dit sjabloon toont alle evenementen van een maand.'
  },
  'view calendar month title' => {
    'lastUpdated' => '1269436488',
    'message' => 'Sjabloon variabelen kalendermaand'
  },
  'view calendar title' => {
    'lastUpdated' => '1269436537',
    'message' => 'Sjabloon variabelen kalender'
  },
  'view calendar week body' => {
    'lastUpdated' => '1189121063',
    'message' => 'Dit template laat alle gebeurtenissen zien in een bepaalde week, gesorteerd per dag.'
  },
  'view calendar week title' => {
    'lastUpdated' => '1269436563',
    'message' => 'Sjabloon variabelen kalenderweek'
  },
  'visitorCacheTimeout description' => {
    'lastUpdated' => '1166194262',
    'message' => 'Het aantal minuten voordat de cache voor bezoekers wordt ververst.'
  },
  'visitorCacheTimeout label' => {
    'lastUpdated' => '1166194288',
    'message' => 'Verlooptijd cache voor bezoekers'
  },
  'weeks' => {
    'lastUpdated' => '1269436293',
    'message' => 'Een functie die de evenementen per dag van die week ophaalt.'
  },
  'workflow generateRecurringEvents' => {
    'lastUpdated' => '1189121145',
    'message' => 'Maak terugkerende gebeurtenissen aan.'
  },
  'workflow generateRecurringEvents description' => {
    'lastUpdated' => '1189121195',
    'message' => 'Deze activiteit maakt terugkerende gebeurtenissen aan in de kalender. Deze activiteit onderhoudt ook terugkerende gebeurtenissen in de toekomst. '
  },
  'workflow updateFeeds' => {
    'lastUpdated' => '1166194315',
    'message' => 'Bijwerken kalenderfeeds'
  },
  'workflow updateFeeds description' => {
    'lastUpdated' => '1166194344',
    'message' => 'Deze activiteit importeert gebeurtenissen uit de kalender vanuit kalenderfeeds'
  },
  'year' => {
    'lastUpdated' => '1189121207',
    'message' => 'Het jaar in vier cijfers.'
  },
  'ymd' => {
    'lastUpdated' => '1189121236',
    'message' => 'De datum van vandaag in yyyy-mm-dd formaat, waarbij yyyy het jaar is, mm de maand en dd de dag.'
  }
}
;

1;
